@@ -17,6 +17,7 @@ from sklearn.utils.validation import (
     _check_sample_weight,
 )
 from .Splitter import Splitter, Snode, Siterator
+from ._version import __version__
 
 
 class Stree(BaseEstimator, ClassifierMixin):
@@ -169,6 +170,11 @@ class Stree(BaseEstimator, ClassifierMixin):
         self.normalize = normalize
         self.multiclass_strategy = multiclass_strategy
 
+    @staticmethod
+    def version() -> str:
+        """Return the version of the package."""
+        return __version__
+
     def _more_tags(self) -> dict:
         """Required by sklearn to supply features of the classifier
         make mandatory the labels array
@@ -470,6 +476,23 @@ class Stree(BaseEstimator, ClassifierMixin):
             tree = None
         return Siterator(tree)
 
+    def graph(self, title="") -> str:
+        """Graphviz code representing the tree
+
+        Returns
+        -------
+        str
+            graphviz code
+        """
+        output = (
+            "digraph STree {\nlabel=<STree "
+            f"{title}>\nfontsize=30\nfontcolor=blue\nlabelloc=t\n"
+        )
+        for node in self:
+            output += node.graph()
+        output += "}\n"
+        return output
+
     def __str__(self) -> str:
         """String representation of the tree
 
